DROP TABLE IF EXISTS `settings`;
DROP TABLE IF EXISTS `userinproject`;
DROP TABLE IF EXISTS `entry`;
DROP TABLE IF EXISTS `task`;
DROP TABLE IF EXISTS `project`;
DROP TABLE IF EXISTS `client`;
DROP TABLE IF EXISTS `user`;


--
-- Table structure for table `client`
--

DROP TABLE IF EXISTS `client`;
CREATE TABLE IF NOT EXISTS `client` (
  `client_id`				int(11)			NOT NULL AUTO_INCREMENT,
  `client_name`				varchar(100)				DEFAULT NULL,
  `client_createdate`		datetime					DEFAULT NULL,
  PRIMARY KEY (`client_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


--
-- Table structure for table `company`
--

DROP TABLE IF EXISTS `settings`;
CREATE TABLE IF NOT EXISTS `settings` (
  `settings_key`		varchar(100) DEFAULT NULL,
  `settings_value`		varchar(100) DEFAULT NULL,
  PRIMARY KEY (`settings_key`, `settings_value`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


--
-- Table structure for table `entry`
--

DROP TABLE IF EXISTS `entry`;
CREATE TABLE IF NOT EXISTS `entry` (
  `entry_id`					int(11)			NOT NULL	AUTO_INCREMENT,
  `entry_date`					date			NOT NULL,
  `entry_starttime`				time						DEFAULT NULL,
  `entry_endtime`				time						DEFAULT NULL,
  `entry_timespan`				int(11)						DEFAULT NULL,
  `entry_description`			varchar(100)				DEFAULT NULL,
  `entry_type`					int(11)			NOT NULL,
  `entry_check_date`			datetime		NOT NULL,
  `entry_check_date_ip`			varchar(100)	NOT NULL,
  `entry_check_starttime`		datetime					DEFAULT NULL,
  `entry_check_starttime_ip`	varchar(100)				DEFAULT NULL,
  `entry_check_endtime`			datetime					DEFAULT NULL,
  `entry_check_endtime_ip`		varchar(100)				DEFAULT NULL,
  `entry_status`				int(1)			NOT NULL	DEFAULT '1',
  `entry_status_date`			datetime					DEFAULT NULL,
  `entry_note`					varchar(1000)				DEFAULT NULL,
  `entry_fk_project_id`			int(11)			NOT NULL,
  `entry_fk_user_id`			int(11)			NOT NULL,
  `entry_fk_task_id`			int(11)						DEFAULT NULL,
  PRIMARY KEY (`entry_id`),
  KEY `cst_entry_task`		(`entry_fk_task_id`),
  KEY `cst_entry_project`	(`entry_fk_project_id`),
  KEY `cst_entry_user`		(`entry_fk_user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Table structure for table `project`
--

DROP TABLE IF EXISTS `project`;
CREATE TABLE IF NOT EXISTS `project` (
  `project_id`					int(11)			NOT NULL AUTO_INCREMENT,
  `project_name`				varchar(100)				DEFAULT NULL,
  `project_createdate`			datetime					DEFAULT NULL,
  `project_status`				int(11)			NOT NULL	DEFAULT '1',
  `project_fk_client_id`		int(11)						DEFAULT NULL,
  PRIMARY KEY (`project_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


--
-- Table structure for table `task`
--

DROP TABLE IF EXISTS `task`;
CREATE TABLE IF NOT EXISTS `task` (
  `task_id`					int(11)			NOT NULL	AUTO_INCREMENT,
  `task_name`				varchar(100)				DEFAULT NULL,
  `task_createdate`			datetime					DEFAULT NULL,
  `task_order`				int(11)			NOT NULL	DEFAULT '1',
  `task_fk_project_id`		int(11)			NOT NULL,
  PRIMARY KEY (`task_id`),
  KEY `cst_task_project` (`task_fk_project_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Table structure for table `user`
--

DROP TABLE IF EXISTS `user`;
CREATE TABLE IF NOT EXISTS `user` (
  `user_id`					int(11)			NOT NULL AUTO_INCREMENT,
  `user_name`				varchar(100)				DEFAULT NULL,
  `user_password`			varchar(100)				DEFAULT NULL,
  `user_email`				varchar(100)	NOT NULL,
  `user_createdate`			datetime					DEFAULT NULL,
  `user_status`				int(1)			NOT NULL	DEFAULT '1',
  `user_level`				int(1)			NOT NULL	DEFAULT '1',
  `user_fk_defaultproject`	int(11)						DEFAULT NULL,
  `user_fk_defaulttask`		int(11)						DEFAULT NULL,
  PRIMARY KEY (`user_id`),
  UNIQUE KEY `user_email` (`user_email`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Table structure for table `userinproject`
--

DROP TABLE IF EXISTS `userinproject`;
CREATE TABLE IF NOT EXISTS `userinproject` (
  `userinproject_fk_user_id` int(11) NOT NULL,
  `userinproject_fk_project_id` int(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`userinproject_fk_user_id`,`userinproject_fk_project_id`),
  KEY `cst_userinproject_project` (`userinproject_fk_project_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


--
-- Constraints for table `entry`
--
ALTER TABLE `entry`
  ADD CONSTRAINT `entry_project` FOREIGN KEY (`entry_fk_project_id`) REFERENCES `project` (`project_id`) ON DELETE CASCADE,
  ADD CONSTRAINT `entry_task` FOREIGN KEY (`entry_fk_task_id`) REFERENCES `task` (`task_id`) ON DELETE CASCADE,
  ADD CONSTRAINT `entry_user` FOREIGN KEY (`entry_fk_user_id`) REFERENCES `user` (`user_id`) ON DELETE CASCADE;

--
-- Constraints for table `task`
--
ALTER TABLE `task`
  ADD CONSTRAINT `task_project` FOREIGN KEY (`task_fk_project_id`) REFERENCES `project` (`project_id`) ON DELETE CASCADE;

--
-- Constraints for table `userinproject`
--
ALTER TABLE `userinproject`
  ADD CONSTRAINT `userinproject_project` FOREIGN KEY (`userinproject_fk_project_id`) REFERENCES `project` (`project_id`) ON DELETE CASCADE,
  ADD CONSTRAINT `userinproject_user` FOREIGN KEY (`userinproject_fk_user_id`) REFERENCES `user` (`user_id`) ON DELETE CASCADE;
  
--
ALTER TABLE `project`
	ADD CONSTRAINT `project_client`	FOREIGN KEY (`project_fk_client_id`) REFERENCES `client` (`client_id`) ON DELETE CASCADE;